..
    Copyright (C) 2019 CESNET.

    Invenio OpenID Connect is free software; you can redistribute it and/or modify it
    under the terms of the MIT License; see LICENSE file for more details.

Changes
=======
